@@ -34,7 +34,6 @@
 #include <QUrl>
 
 #include <KWindowSystem>
-#include <KNotification>
 #include <KConfigGroup>
 #include <KIconLoader>
 #include <KUser>
@@ -145,7 +144,8 @@ AuthDialog::AuthDialog(const QString &actionId,
     userCB->hide();
     lePassword->setFocus();
 
-    errorMessageKTW->hide();
+    errorMessageWidget->setMessageType(KMessageWidget::Error);
+    errorMessageWidget->hide();
 
     // If there is more than 1 identity we will show the combobox for user selection
     if (identities.size() > 1) {
@@ -305,7 +305,9 @@ QString AuthDialog::password() const
 
 void AuthDialog::authenticationFailure()
 {
-    errorMessageKTW->setText(i18n("Authentication failure, please try again."), KTitleWidget::ErrorMessage);
+    errorMessageWidget->setText(i18n("Authentication failure, please try again."));
+    errorMessageWidget->animatedShow();
+
     QFont bold = font();
     bold.setBold(true);
     lblPassword->setFont(bold);
@@ -314,32 +316,6 @@ void AuthDialog::authenticationFailure()
     lePassword->setFocus();
 }
 
-void AuthDialog::showEvent(QShowEvent *event)
-{
-    QDialog::showEvent(event);
-    if (winId() != KWindowSystem::activeWindow())
-    {
-        KNotification *notification = new KNotification("authenticate", this,
-                                                        KNotification::Persistent | KNotification::CloseWhenWidgetActivated);
-        qDebug() << "Notificate: " << notification->eventId();
-        notification->setComponentName("policykit1-kde");
-        notification->setText(m_message);
-        notification->setPixmap(QIcon::fromTheme("dialog-password").pixmap(KIconLoader::SizeMedium));
-        notification->setActions(QStringList() << i18n("Switch to dialog") << i18n("Cancel"));
-
-        connect(notification, SIGNAL(activated(uint)), this, SLOT(notificationActivated(uint)));
-        notification->sendEvent();
-    }
-}
-
-void AuthDialog::notificationActivated(unsigned int action)
-{
-    qDebug() << "notificationActivated: " << action;
-    if (action == 1) {
-        KWindowSystem::forceActiveWindow(winId());
-    }
-}
-
 AuthDetails::AuthDetails(const PolkitQt1::Details &details,
                          const PolkitQt1::ActionDescription &actionDescription,
                          const QString &appname,
